
glovebox
========
a package for storing temporary files without fuss

<nobr><img src="https://img.shields.io/pypi/v/glovebox" alt="version"/></nobr>
<nobr><img src="https://img.shields.io/travis/com/lockhartlab/glovebox/master"  alt="build-status-master"/></nobr>
<nobr><img src="https://img.shields.io/codecov/c/github/lockhartlab/glovebox/master" alt="coverage-master"/></nobr>

<hr>

note that this package is **still in development**  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

yet, install simply by calling ```pip install glovebox```

